# pytest-rocketchat
Inspired by pytest-slack & pytest-messenger.

Pytest to RocketChat reporting plugin

## Requirements
- Python >= 3.6

## Installation
You can install "pytest-rocketchat" via [pip](https://pypi.python.org/pypi/pip/):
```
$ pip install pytest-rocketchat
```
If you encounter any problems, please file an [issue](https://github.com/aleksandr-kotlyar/pytest-rocketchat/issues) along with a detailed description.
